@@ -1,11 +1,14 @@
 import sys
 import time
 import json
-import logging
 import traceback
 import importlib
 from collections import OrderedDict
-import __builtin__      # Do not remove
+
+try:
+    import __builtin__      # Do not remove
+except ImportError:
+    import builtins as __builtin__
 
 from Qt.QtCore import *
 from Qt.QtWidgets import *
@@ -41,11 +44,12 @@ class DccServer(QObject, object):
         node = data.get('node', None)
         add_to_selection = data.get('add_to_selection', False)
         if node:
-            tp.Dcc.select_object(node, replace_selection=not add_to_selection)
+            tp.Dcc.select_node(node, replace_selection=not add_to_selection)
         reply['success'] = True
 
     def selected_nodes(self, data, reply):
-        selected_nodes = tp.Dcc.selected_nodes()
+        full_path = data.get('full_path', True)
+        selected_nodes = tp.Dcc.selected_nodes(full_path=full_path)
         reply['success'] = True
         reply['result'] = selected_nodes
 
