@@ -10,6 +10,8 @@ import logging
 import tpDcc
 from tpDcc.libs.python import decorators
 
+LOGGER = logging.getLogger('tpDcc-core')
+
 
 class LogsManager(object):
     def __init__(self):
@@ -23,15 +25,16 @@ class LogsManager(object):
         """
 
         if not tool_id:
-            return logging.getLogger('tpDcc')
+            return logging.getLogger('tpDcc-core')
 
         tool_data = tpDcc.ToolsMgr().get_plugin_data_from_id(tool_id)
         if not tool_data:
-            return logging.getLogger('tpDcc')
+            # LOGGER.warning('No logger found for tool with id: {}'.format(tool_id))
+            return logging.getLogger('tpDcc-core')
 
         logging_file = tool_data.get('logging_file', None)
         if not logging_file:
-            return logging.getLogger('tpDcc')
+            return logging.getLogger('tpDcc-core')
 
         logging.config.fileConfig(logging_file, disable_existing_loggers=False)
         # tool_logger_level_env = '{}_LOG_LEVEL'.format(pkg_loader.fullname.replace('.', '_').upper())
