@@ -89,7 +89,7 @@ class ToolsManager(plugin.PluginsManager, object):
             try:
                 mod = importer.find_module(sub_module_name).load_module(sub_module_name)
             except Exception as exc:
-                tp.logger.error('Impossible to register plugin: "{}"'.format(plugin_path), exc_info=True)
+                # tp.logger.error('Impossible to register plugin: "{}"'.format(plugin_path), exc_info=True)
                 continue
 
             if qname.endswith('__version__') and hasattr(mod, '__version__'):
@@ -179,7 +179,8 @@ class ToolsManager(plugin.PluginsManager, object):
         if os.path.isdir(resources_path):
             tp.ResourcesMgr().register_resource(resources_path, key='tools')
         else:
-            tp.logger.debug('No resources directory found for plugin "{}" ...'.format(_plugin_name))
+            pass
+            # tp.logger.debug('No resources directory found for plugin "{}" ...'.format(_plugin_name))
 
         # Register DCC specific resources
         if dcc_loader and dcc_config:
@@ -190,7 +191,8 @@ class ToolsManager(plugin.PluginsManager, object):
             if os.path.isdir(resources_path):
                 tp.ResourcesMgr().register_resource(resources_path, key='plugins')
             else:
-                tp.logger.debug('No resources directory found for plugin "{}" ...'.format(_plugin_name))
+                pass
+                # tp.logger.debug('No resources directory found for plugin "{}" ...'.format(_plugin_name))
 
         # Create tool loggers directory
         default_logger_dir = os.path.normpath(os.path.join(os.path.expanduser('~'), 'tpDcc', 'logs', 'tools'))
